==> apache-camel-3.4.4-src.zip: apache-camel-3.4.4/components/camel-crypto/src/test/java/org/apache/camel/converter/crypto/PGPKeyAccessDataFormatTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.converter.crypto;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.test.junit5.CamelTestSupport;

public class PGPKeyAccessDataFormatTest extends CamelTestSupport {

    @Override
    protected RouteBuilder createRouteBuilder() {

        return new RouteBuilder() {
            public void configure() throws Exception {

                PGPPublicKeyAccessor publicKeyAccessor = new DefaultPGPPublicKeyAccessor(PGPDataFormatTest.getPublicKeyRing());
                PGPSecretKeyAccessor secretKeyAccessor = new DefaultPGPSecretKeyAccessor(PGPDataFormatTest.getSecKeyRing(), "sdude", "BC");
                try (PGPKeyAccessDataFormat dt = new PGPKeyAccessDataFormat()) {
                    dt.setPublicKeyAccessor(publicKeyAccessor);
                    dt.setSecretKeyAccessor(secretKeyAccessor);
                    dt.setKeyUserid("sdude");
                    dt.setSignatureKeyUserid("sdude");
                }
            }
        };
    }

}

==> apache-camel-3.11.7-src.zip: apache-camel-3.11.7/components/camel-crypto/src/test/java/org/apache/camel/converter/crypto/PGPKeyAccessDataFormatTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.converter.crypto;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.test.junit5.CamelTestSupport;

public class PGPKeyAccessDataFormatTest extends CamelTestSupport {

    @Override
    protected RouteBuilder createRouteBuilder() {

        return new RouteBuilder() {
            public void configure() throws Exception {

                PGPPublicKeyAccessor publicKeyAccessor = new DefaultPGPPublicKeyAccessor(PGPDataFormatTest.getPublicKeyRing());
                PGPSecretKeyAccessor secretKeyAccessor
                        = new DefaultPGPSecretKeyAccessor(PGPDataFormatTest.getSecKeyRing(), "sdude", "BC");
                try (PGPKeyAccessDataFormat dt = new PGPKeyAccessDataFormat()) {
                    dt.setPublicKeyAccessor(publicKeyAccessor);
                    dt.setSecretKeyAccessor(secretKeyAccessor);
                    dt.setKeyUserid("sdude");
                    dt.setSignatureKeyUserid("sdude");
                }
            }
        };
    }

}
